tryParent<T extends Object> abstract method
T?
tryParent<T extends Object>()
Attempts to resolve a dependency of type T from the parent scope.
Returns null when the parent scope does not contain the type.
Implementation
T? tryParent<T extends Object>();